==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/BaFz.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.qxdm;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 发证属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fz"
)
public class BaFz implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    @ywh
    private String ywh;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String fzry;

    @XmlAttribute
    private Date fzsj;

    @XmlAttribute
    private String fzmc;

    @XmlAttribute
    private int fzsl;

    @XmlAttribute
    private String hfzsh;

    @XmlAttribute
    private String lzrxm;

    @XmlAttribute
    private String lzrzjlb;

    @XmlAttribute
    private String lzrzjhm;

    @XmlAttribute
    @Nullable
    private String lzrdh;

    @XmlAttribute
    @Nullable
    private String lzrdz;

    @XmlAttribute
    @Nullable
    private String lzryb;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYwh() {
        return ywh;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getFzry() {
        return fzry;
    }

    public Date getFzsj() {
        return fzsj;
    }

    public String getFzmc() {
        return fzmc;
    }

    public int getFzsl() {
        return fzsl;
    }

    public String getHfzsh() {
        return hfzsh;
    }

    public String getLzrxm() {
        return lzrxm;
    }

    public String getLzrzjlb() {
        return lzrzjlb;
    }


    public String getLzrdh() {
        return lzrdh;
    }

    public String getLzrdz() {
        return lzrdz;
    }

    public String getLzryb() {
        return lzryb;
    }

    public String getBz() {
        return bz;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setFzry(String fzry) {
        this.fzry = fzry;
    }

    public void setFzsj(Date fzsj) {
        this.fzsj = fzsj;
    }

    public void setFzmc(String fzmc) {
        this.fzmc = fzmc;
    }

    public void setFzsl(int fzsl) {
        this.fzsl = fzsl;
    }

    public void setHfzsh(String hfzsh) {
        this.hfzsh = hfzsh;
    }

    public void setLzrxm(String lzrxm) {
        this.lzrxm = lzrxm;
    }

    public void setLzrzjlb(String lzrzjlb) {
        this.lzrzjlb = lzrzjlb;
    }


    public void setLzrdh(String lzrdh) {
        this.lzrdh = lzrdh;
    }

    public void setLzrdz(String lzrdz) {
        this.lzrdz = lzrdz;
    }

    public void setLzryb(String lzryb) {
        this.lzryb = lzryb;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getLzrzjhm() {
        return lzrzjhm;
    }

    public void setLzrzjhm(String lzrzjhm) {
        this.lzrzjhm = lzrzjhm;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }
}

==> realestate-supervise-common-1.1.0-20241231.014802-54-sources.jar: cn/gtmap/realestate/supervise/entity/BaFz.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.qxdm;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 发证属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fz"
)
public class BaFz implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    @ywh
    private String ywh;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String fzry;

    @XmlAttribute
    private Date fzsj;

    @XmlAttribute
    private String fzmc;

    @XmlAttribute
    private int fzsl;

    @XmlAttribute
    private String hfzsh;

    @XmlAttribute
    private String lzrxm;

    @XmlAttribute
    private String lzrzjlb;

    @XmlAttribute
    private String lzrzjhm;

    @XmlAttribute
    @Nullable
    private String lzrdh;

    @XmlAttribute
    @Nullable
    private String lzrdz;

    @XmlAttribute
    @Nullable
    private String lzryb;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ysxlh;

    public String getYsxlh() {
        return ysxlh;
    }

    public void setYsxlh(String ysxlh) {
        this.ysxlh = ysxlh;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYwh() {
        return ywh;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getFzry() {
        return fzry;
    }

    public Date getFzsj() {
        return fzsj;
    }

    public String getFzmc() {
        return fzmc;
    }

    public int getFzsl() {
        return fzsl;
    }

    public String getHfzsh() {
        return hfzsh;
    }

    public String getLzrxm() {
        return lzrxm;
    }

    public String getLzrzjlb() {
        return lzrzjlb;
    }


    public String getLzrdh() {
        return lzrdh;
    }

    public String getLzrdz() {
        return lzrdz;
    }

    public String getLzryb() {
        return lzryb;
    }

    public String getBz() {
        return bz;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setFzry(String fzry) {
        this.fzry = fzry;
    }

    public void setFzsj(Date fzsj) {
        this.fzsj = fzsj;
    }

    public void setFzmc(String fzmc) {
        this.fzmc = fzmc;
    }

    public void setFzsl(int fzsl) {
        this.fzsl = fzsl;
    }

    public void setHfzsh(String hfzsh) {
        this.hfzsh = hfzsh;
    }

    public void setLzrxm(String lzrxm) {
        this.lzrxm = lzrxm;
    }

    public void setLzrzjlb(String lzrzjlb) {
        this.lzrzjlb = lzrzjlb;
    }


    public void setLzrdh(String lzrdh) {
        this.lzrdh = lzrdh;
    }

    public void setLzrdz(String lzrdz) {
        this.lzrdz = lzrdz;
    }

    public void setLzryb(String lzryb) {
        this.lzryb = lzryb;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getLzrzjhm() {
        return lzrzjhm;
    }

    public void setLzrzjhm(String lzrzjhm) {
        this.lzrzjhm = lzrzjhm;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }
}
